from abc import ABC, abstractmethod
from typing import Optional

from cpl_query.extension import List
from gismo_data.model.client import Client


class ClientRepositoryABC(ABC):

    @abstractmethod
    def __init__(self): pass
    
    @abstractmethod
    def get_clients(self) -> List[Client]: pass
    
    @abstractmethod
    def get_client_by_id(self, id: int) -> Client: pass
    
    @abstractmethod
    def get_client_by_discord_id(self, discord_id: int) -> Client: pass
    
    @abstractmethod
    def find_client_by_discord_id(self, discord_id: int) -> Optional[Client]: pass
    
    @abstractmethod
    def find_client_by_server_id(self, server_id: int) -> Optional[Client]: pass
    
    @abstractmethod
    def find_client_by_discord_id_and_server_id(self, discord_id: int, server_id: int) -> Optional[Client]: pass
    
    @abstractmethod
    def add_client(self, client: Client): pass
    
    @abstractmethod
    def update_client(self, client: Client): pass
    
    @abstractmethod
    def delete_client(self, client: Client): pass

    @abstractmethod
    def apppend_sent_message_count(self, id: int, server_id: int, value: int): pass

    @abstractmethod
    def apppend_received_message_count(self, id: int, server_id: int, value: int): pass

    @abstractmethod
    def apppend_deleted_message_count(self, id: int, server_id: int, value: int): pass

    @abstractmethod
    def apppend_received_command_count(self, id: int, server_id: int, value: int): pass

    @abstractmethod
    def apppend_moved_users_count(self, id: int, server_id: int, value: int): pass
